# FONTIFY by Mike Thai (c) 2024/10/11
# swarliwyth@gmail.com
#
# Uruchom konsole (Win+R cmd ENTER):
# pip install fonttools
# a potem odpal skrypt, np.:
# python C:\Users\Mike\Desktop\fontify.py A_ C:\Users\Mike\Desktop\fonty
# po wszystkim będziesz miał nowe fonty w katalogu C:\Users\Mike\Desktop\fonty\new
#
# jak masz Winde to zrestartuj system po zainstalowaniu zmodyfikowanych czcionek
# system buforuje nazwy fontów
#
import os
import sys
from fontTools.ttLib import TTFont

# Sprawdź, czy podano argumenty z katalogiem i prefiksem
if len(sys.argv) != 3:
    print("Użycie: python fontify.py <prefiks> <ścieżka_do_katalogu_z_czcionkami>")
    sys.exit(1)

# Prefiks do dodania do nazwy czcionki
font_prefix = sys.argv[1]  # Zmienna prefiks

# Ścieżka do katalogu z czcionkami przekazana jako argument
fonts_directory = sys.argv[2]

# Katalog docelowy na zmodyfikowane czcionki
output_directory = os.path.join(fonts_directory, "new")

# Sprawdź, czy katalog istnieje, jeśli nie, utwórz go
if not os.path.exists(output_directory):
    os.makedirs(output_directory)

# Iteruj przez pliki w katalogu
font_files = [f for f in os.listdir(fonts_directory) if f.endswith('.otf') or f.endswith('.ttf')]
total_fonts = len(font_files)

for index, filename in enumerate(font_files, 1):
    font_path = os.path.join(fonts_directory, filename)  # Pełna ścieżka do pliku czcionki

    try:
        # Otwórz czcionkę
        font = TTFont(font_path)

        # Odczytaj oryginalną nazwę czcionki
        original_full_name = font['name'].getName(4, 3, 1, 0x409)  # Full Name dla Microsoftu

        # Dodaj prefiks do oryginalnej nazwy czcionki
        new_full_name = f"{font_prefix}{original_full_name.toStr()}"
        print(f"[{index}/{total_fonts}] {filename} -> {new_full_name}")

        # Zmieniamy Full Name, PostScript Name, Family Name i inne krytyczne rekordy
        for record in font['name'].names:
            # Zmieniamy odpowiednie rekordy (łącznie z NameID 1 dla testu)
            if record.nameID in {1, 3, 4, 6, 16, 17, 18}:
                new_name = new_full_name if record.nameID != 6 else new_full_name.replace(" ", "")
                record.string = new_name.encode('utf-16-be') if record.platformID == 3 else new_name.encode('macroman')

        # Zapisz zmodyfikowaną czcionkę w katalogu 'new'
        new_font_path = os.path.join(output_directory, f"{font_prefix}{filename}")  # Zmieniona nazwa pliku
        font.save(new_font_path)

    except Exception as e:
        print(f"Błąd przy otwieraniu czcionki {filename}: {e}")

print(f"Skrypt zakończony. Nowe czcionki są dostępne w: {output_directory}")